summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorwang_zhiqiang <wang_zhiqiang@dl.cn.nexty-ele.com>2018-12-12 11:05:57 +0800
committerwang_zhiqiang <wang_zhiqiang@dl.cn.nexty-ele.com>2018-12-19 17:14:54 +0800
commit0f8ad02e76edd2ca93a4a5a475bb3e832685f20f (patch)
tree5b63efe7775d91bc49f4be01d5a436ab99c7d002
parentd366f0cf37187d46e0fd752772bdbd34e2b39ebf (diff)
Use Event_ShowWindow instead of Event_TapShortcutguppy_6.99.3guppy/6.99.36.99.3
The interface of homescreen service will be changed then, use Event_ShowWindow instead of Event_TapShortcut. Related changes: agl-service-homescreen: https://gerrit.automotivelinux.org/gerrit/#/c/17929/ libhomescreen: https://gerrit.automotivelinux.org/gerrit/#/c/17931/ libqthomescreen: https://gerrit.automotivelinux.org/gerrit/#/c/17933/ BUG-AGL: SPEC-1931 Change-Id: Icc1533243941e2a49aa0a35d3948bbc71ef477ac Signed-off-by: wang_zhiqiang <wang_zhiqiang@dl.cn.nexty-ele.com>
-rw-r--r--app/main.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/app/main.cpp b/app/main.cpp
index 5b58bd0..f5c1ee3 100644
--- a/app/main.cpp
+++ b/app/main.cpp
@@ -90,9 +90,9 @@ int main(int argc, char *argv[])
// HomeScreen
hs->init(port, token.c_str());
- // Set the event handler for Event_TapShortcut which will activate the surface for windowmanager
- hs->set_event_handler(LibHomeScreen::Event_TapShortcut, [qwm, graphic_role](json_object *object){
- qDebug("Surface %s got tapShortcut\n", graphic_role.toStdString().c_str());
+ // Set the event handler for Event_ShowWindow which will activate the surface for windowmanager
+ hs->set_event_handler(LibHomeScreen::Event_ShowWindow, [qwm, &graphic_role](json_object *object){
+ qDebug("Surface %s got showWindow\n", graphic_role.toStdString().c_str());
qwm->activateWindow(graphic_role);
});